import * as cdk from 'aws-cdk-lib';
import { Construct } from 'constructs';
import { Vehicle } from './vehicle';
export declare class CollectionScheme {
    protected scheme: object;
    constructor();
    toObject(): object;
}
export declare class TimeBasedCollectionScheme extends CollectionScheme {
    constructor(period: cdk.Duration);
}
export declare class CampaignSignal {
    private signal;
    constructor(name: string, maxSampleCount?: number, minimumSamplingInterval?: cdk.Duration);
    toObject(): object;
}
export interface CampaignProps {
    readonly name: string;
    readonly target: Vehicle;
    readonly collectionScheme: CollectionScheme;
    readonly signals: CampaignSignal[];
    readonly autoApprove?: boolean;
    readonly useS3?: boolean;
    readonly campaignS3arn: string;
    readonly timestreamArn: string;
    readonly fwTimestreamRole: string;
}
/**

export class Campaign extends Construct {
  readonly name: string = '';
  readonly arn: string = '';
  readonly target: Vehicle = ({} as Vehicle);

  constructor(scope: Construct, id: string, props: CampaignProps) {
    super(scope, id);

    (this.name as string) = props.name;
    this.arn = `arn:aws:iotfleetwise:${cdk.Aws.REGION}:${cdk.Aws.ACCOUNT_ID}:vehicle/${props.target}`;
    (this.target as Vehicle) = props.target;

    const handler = new Handler(this, 'Handler', {
      handler: 'campaignhandler.on_event',
    });

    const resource = new cdk.CustomResource(this, 'Resource', {
      serviceToken: Provider.getOrCreate(this, handler).provider.serviceToken,
      properties: {
        name: this.name,
        signal_catalog_arn: this.target.vehicleModel.signalCatalog.arn,
        data_destination_configs: JSON.stringify(props.dataDestinationConfigs.map(s => s.toObject())),
        target_arn: this.target.arn,
        collection_scheme: JSON.stringify(props.collectionScheme.toObject()),
        signals_to_collect: JSON.stringify(props.signals.map(s => s.toObject())),
        auto_approve: props.autoApprove || false,
      },
    });
    resource.node.addDependency(this.target);
  }
}
*/
export declare class Campaign extends Construct {
    readonly name: string;
    readonly arn: string;
    readonly target: Vehicle;
    constructor(scope: Construct, id: string, props: CampaignProps);
}
